pitchtools.list_unordered_named_chromatic_pitch_pairs_in_expr
=============================================================

.. autofunction:: abjad.tools.pitchtools.list_unordered_named_chromatic_pitch_pairs_in_expr.list_unordered_named_chromatic_pitch_pairs_in_expr
